##############################################################################
#
# Copyright (c) 2002 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Zope Object Database: object database and persistence

The Zope Object Database provides an object-oriented database for
Python that provides a high-degree of transparency. Applications can
take advantage of object database features with few, if any, changes
to application logic.  ZODB includes features such as a plugable storage
interface, rich transaction support, and undo.
"""

import sys
from distutils.core import setup
from distutils.extension import Extension

ExtensionClass = Extension(name = 'ExtensionClass',
                           sources = ['ExtensionClass/src/ExtensionClass.c'])

Acquisition = Extension(name = 'Acquisition',
                        sources = ['ExtensionClass/src/Acquisition.c'])

ComputedAttribute = Extension(name = 'ComputedAttribute',
                       sources = ['ExtensionClass/src/ComputedAttribute.c'])

MethodObject = Extension(name = 'MethodObject',
                         sources = ['ExtensionClass/src/MethodObject.c'])

Missing = Extension(name = 'Missing',
                    sources = ['ExtensionClass/src/Missing.c'])

MultiMapping = Extension(name = 'MultiMapping',
                         sources = ['ExtensionClass/src/MultiMapping.c'])

Record = Extension(name = 'Record', sources = ['ExtensionClass/src/Record.c'])

Sync = Extension(name = 'Sync', sources = ['ExtensionClass/src/Sync.c'])

ThreadLock = Extension(name = 'ThreadLock',
                       sources = ['ExtensionClass/src/ThreadLock.c'])

include = ['ExtensionClass/src', 'ZODB']

cPersistence = Extension(name = 'ZODB.cPersistence',
                         include_dirs = include,
                         sources= ['ZODB/cPersistence.c']
                         )

cPickleCache = Extension(name = 'ZODB.cPickleCache',
                         include_dirs = include,
                         sources= ['ZODB/cPickleCache.c']
                         )

TimeStamp = Extension(name = 'ZODB.TimeStamp',
                      define_macros = [('USE_EXTENSION_CLASS', 1)],
                      include_dirs = include,
                      sources= ['ZODB/TimeStamp.c']
                      )

coptimizations = Extension(name = 'ZODB.coptimizations',
                           include_dirs = include,
                           sources= ['ZODB/coptimizations.c']
                           )

winlock = Extension(name = 'ZODB.winlock',
                    include_dirs = include,
                    sources = ['ZODB/winlock.c']
                    )

oob = Extension(name = "BTrees._OOBTree",
                include_dirs = include,
                sources = ['BTrees/_OOBTree.c'],
                )

oib = Extension(name = "BTrees._OIBTree",
                include_dirs = include,
                sources = ['BTrees/_OIBTree.c'],
                )

iib = Extension(name = "BTrees._IIBTree",
                include_dirs = include,
                sources = ['BTrees/_IIBTree.c'],
                define_macros = [('EXCLUDE_INTSET_SUPPORT', None)],
                )

iob = Extension(name = "BTrees._IOBTree",
                include_dirs = include,
                sources = ['BTrees/_IOBTree.c'],
                define_macros = [('EXCLUDE_INTSET_SUPPORT', None)],
                )

fsb = Extension(name = "BTrees._fsBTree",
                include_dirs = include,
                sources = ['BTrees/_fsBTree.c'],
                define_macros = [('EXCLUDE_INTSET_SUPPORT', None)],
                )

bsddbhelper = Extension(name = 'BDBStorage._helper',
                        sources = ['BDBStorage/_helper.c'])

packages = ['BTrees', 'BTrees.tests',
            'ZODB', 'ZODB.tests',
            "Persistence",
            "ThreadedAsync",
            "zLOG", "zLOG.tests",
            "zdaemon", "zdaemon.tests",
            "ZopeUndo", "ZopeUndo.tests",
            ]

package_dir = {}

packages.extend(["BDBStorage", "BDBStorage.tests"])
package_dir['BDBStorage'] = 'BDBStorage'

# This version of ZODB ships with two incompatible versions of ZEO.
# The recommended version is ZEO 2.0, which is the focus of current
# ZEO development.  It is, however, incompatible with ZEO 1.0, which
# shipped with earlier versions of ZODB.  To upgrade, all ZEO clients
# and servers must be upgraded at the same time.
#
# Since it may be inconvenient to upgrade at the same time this
# software is installed, you can pass --with-zeo1 to setup.py on the
# command-line.  This will build, test, and install ZEO 1.0 instead of
# ZEO 2.0.
#
# We've made no effort to make the -b option to test.py work.  If you
# pass --with-zeo1 to setup.py and then run test.py -b, it will
# clobber ZEO 1.0 and install ZEO 2.0.

# peek at the command-line arguments
ZEO_VERSION = 2
if "--with-zeo1" in sys.argv:
    ZEO_VERSION = 1
    sys.argv.remove("--with-zeo1")
    
if ZEO_VERSION == 1:
    packages += ["ZEO", "ZEO.tests"]
    package_dir["ZEO"] = "ZEO1"
else:
    packages += ["ZEO", "ZEO.zrpc", "ZEO.tests"]

ext_modules = [ExtensionClass, Acquisition, ComputedAttribute,
               MethodObject, Missing, MultiMapping, Sync,
               ThreadLock, Record, cPersistence, cPickleCache,
               TimeStamp, coptimizations, winlock, oob, oib,
               iib, iob, fsb,
               ]

# Don't build the helper unless using at least Python 2.2
if sys.hexversion >= 0x020200F0:
    ext_modules.append(bsddbhelper)

doclines = __doc__.split("\n")

setup(name="ZODB3",
      version="3.1.1",
      maintainer="Zope Corporation",
      maintainer_email="zodb-dev@zope.org",
      url = "http://www.zope.org/Wikis/ZODB/FrontPage",
      packages = packages,
      package_dir = package_dir,
      ext_modules = ext_modules,
      headers = ['ExtensionClass/src/ExtensionClass.h', 'ZODB/cPersistence.h'],
      license = "http://www.zope.org/Resources/ZPL",
      platforms = ["yes"], #
      description = doclines[0],
      long_description = "\n".join(doclines[2:])
      )
